magneticalc.SidebarLeft.SidebarLeft

# ``magneticalc`.`SidebarLeft`.`SidebarLeft``

class documentation

`class SidebarLeft(QScrollArea):`

Constructor: `SidebarLeft(gui)`

View In Hierarchy

SidebarLeft class.

Method | `__init__` | Populates the left sidebar.
Class Variable | `MaximumWidth` | Undocumented
Class Variable | `VerticalSpacing` | Undocumented
Instance Variable | `gui` | Undocumented
Instance Variable | `sampling_volume_widget` | Undocumented
Instance Variable | `wire_widget` | Undocumented

def __init__(self, gui: `GUI`):

Populates the left sidebar.

Parameters
gui: `GUI` | GUI

MaximumWidth: `int` =

Undocumented

VerticalSpacing: `int` =

Undocumented

gui =

Undocumented

sampling_volume_widget =

Undocumented

wire_widget =

Undocumented